Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(427)

Unified Diff: runtime/vm/stub_code_x64.cc

Issue 2719603002: Rename Closure instance field type_arguments_ to instantiator_. (Closed)
Patch Set: work in progress Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/stub_code_mips.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/stub_code_x64.cc
diff --git a/runtime/vm/stub_code_x64.cc b/runtime/vm/stub_code_x64.cc
index a2f123e3a782b2d626099acf3b264378b31fa80c..f3a7f12ab8c0e314a2a2529ea9988b46322ea88d 100644
--- a/runtime/vm/stub_code_x64.cc
+++ b/runtime/vm/stub_code_x64.cc
@@ -1747,11 +1747,12 @@ static void GenerateSubtypeNTestCacheStub(Assembler* assembler, int n) {
__ addq(RDX, Immediate(Array::data_offset() - kHeapObjectTag));
// RDX: Entry start.
// R10: instance class id.
// R13: instance type arguments.
Label loop, found, not_found, next_iteration;
__ SmiTag(R10);
__ cmpq(R10, Immediate(Smi::RawValue(kClosureCid)));
__ j(NOT_EQUAL, &loop, Assembler::kNearJump);
+ __ movq(R13, FieldAddress(RAX, Closure::instantiator_offset()));
__ movq(R10, FieldAddress(RAX, Closure::function_offset()));
// R10: instance class id as Smi or function.
__ Bind(&loop);
@@ -1747,11 +1747,12 @@ static void GenerateSubtypeNTestCacheStub(Assembler* assembler, int n) {
// RDX: Entry start.
// R10: instance class id.
- // R13: instance type arguments.
+ // R13: instance type arguments (still null if closure).
Label loop, found, not_found, next_iteration;
__ SmiTag(R10);
« no previous file with comments | « runtime/vm/stub_code_mips.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698